%Federico Ravenna and Carl Walsh
%"Worker heterogeneity, selection, and employment dynamics in a pandemic"
% Journal of Money, Credit and Banking
%First draft: April 2020
% Current draft: August 2021
%%%%
% SEE README JMCB RAVENNA WALSH 2021.DOC
%%%%

%AMENDED 23 April 2021
clear all
close all

%%%%%%%%%%%%%%%%% NOTE 2021
% carl200_irf >> irf_cali >> benchmark (PLANNER)
% carl200_irf_eu >> irf_cali_expansionary >> MARKET
%%%%%%%%%%%%%%%%%

% Federico Update 7 May 2020
%Produces specific set of plots, for paper
%used to compare baseline vs alternative
%loads data, so can also be used with single baseline experiment
%first needs to use carl200plot_e1_XXXXXX
%
%Built from irf_carl200_dem_persistent.m
%Added at end part of irf_carl200_dem_ZLB.m

% reads the IRF variables generated by Dynare
% listed as : 'variable name in lgy_''name of shock'
% generated by carl200 and carl200_eu

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% FIGURE 1 // FIG A - SHOCKS - ONLY MKT

load carl200_irf_eu
HORIZON = size(xit_e1,1);
zzero=zeros(1,HORIZON);
Time_axis = [1:HORIZON];

irf_cali_expansionary = [y_e1, rhot_e1, d_e1, z_e1 ];

   newpp=[0.25 , 0.25 , 8, 8];
      grid on
set(gcf,'PaperOrientation','portrait')
set(gcf,'PaperPosition',newpp)



%MODEL SPECIFIC variables
variable=[1:1:4];

varname1 =   ['               nominal interest rate ']; 
varname = repmat(varname1(1,:),8,1);
varname(3,:)=['Demand shock                         '];
varname(4,:)=['Separation rate shock                '];
varname(2,:)=['Total separation rate                '];
varname(1,:)=['Output                               '];

for counter = 1:1;
for index = 1:size(variable,2);
   newpp=[0.25 , 0.25 , 8, 8];
      grid on
set(gcf,'PaperOrientation','portrait')
set(gcf,'PaperPosition',newpp)
%set(gca,'XTick',[ 4 8 12 16 20])
%set(gca,'XTickLabel',{'1', '2', '3', '4', '5'})
%set(findobj('Type','line'),'LineWidth',2)

%if index ==1 | index==2 | index == 3 
   
    subplot(2,2,index),plot(...
                Time_axis,zzero(1,:),':',Time_axis,irf_cali_expansionary(:, 1+1*(index-1)+(counter-1)),'k')
        
   
xlim([1 HORIZON]);
    grid on
	title(varname(variable(index),:))
 %   set(gca,'XTick',[ 4 8 12 16 20])
%set(gca,'XTickLabel',{'1', '2', '3', '4', '5'})
set(findobj('Type','line'),'LineWidth',1)

		if index == 1
            if counter == 1
ylabel('COVID Scenario')
            elseif counter == 2
			%ylabel('technology shock')
            else
			%ylabel('policy shock')
            end
      end;
       if index == 3,
          xlabel(['']);	%second rule
		elseif index ==4,
         xlabel(['']); %first rule
       
       else,
		end;	
       
%else
    
%end
end

figure
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% FIGURE 2bis - FIG B BIS Unempl rate, PP from ss (subtract ss)
%%%%% COLOR AREA so areas sum

load carl200_irf_eu
HORIZON = size(xit_e1,1);
zzero=zeros(1,HORIZON);
Time_axis = [1:HORIZON];

share_nl = nl_e1*nl_ss./(n_e1*n_ss)*100;
share_nh = nh_e1*nh_ss./(n_e1*n_ss)*100;
share_scaled_ul = share_nl.*(unempl-u_ss*100)/100
share_scaled_uh = share_nh.*(unempl-u_ss*100)/100

   newpp=[0.25 , 0.25 , 8, 8];
      grid on
set(gcf,'PaperOrientation','portrait')
set(gcf,'PaperPosition',newpp)

newpp=[0.25 , 0.25 , 8, 8];
      grid on
set(gcf,'PaperOrientation','portrait')
set(gcf,'PaperPosition',newpp)
%set(gca,'XTick',[ 4 8 12 16 20])
%set(gca,'XTickLabel',{'1', '2', '3', '4', '5'})
%set(findobj('Type','line'),'LineWidth',2)

    subplot(1,2,1),plot(Time_axis,u_e1*u_ss,'k',...
        Time_axis,uh_e1*uh_ss,'--k.',Time_axis,ul_e1*ul_ss,'-.k',Time_axis,zzero(1,:),':')
   
xlim([1 HORIZON]);
    grid on
		legend('total',...
    'high efficiency workers', 'low efficiency workers')
 grid on
 title('Unemployment Rate - log-change ')

 ylabel('COVID Scenario')
 
    %subplot(1,2,2),plot(Time_axis,u_e1*u_ss,'k',...
    subplot(1,2,2),plot(Time_axis,share_scaled_ul,'k',...
        Time_axis,share_scaled_uh,'--k.', Time_axis,zzero(1,:),':')
   
xlim([1 HORIZON]);
    grid on
		legend('total',...
    'high efficiency workers')
 grid on
 title('Unemployment shares')
 
 %   set(gca,'XTick',[ 4 8 12 16 20])
%set(gca,'XTickLabel',{'1', '2', '3', '4', '5'})
set(findobj('Type','line'),'LineWidth',1)

figure


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% FIGURE 5 - FIG C /  gamat abar psi mu


load carl200_irf_eu
psi_e1=-(gamat_e1+rhon_e1)/(1-gamat_ss*rhon_ss)*rhon_ss*gamat_ss

irf_cali_expansionary = [gamat_e1*gamat_ss, abar_e1*rhon_ss, mu_e1, psi_e1];

   newpp=[0.25 , 0.25 , 8, 8];
      grid on
set(gcf,'PaperOrientation','portrait')
set(gcf,'PaperPosition',newpp)

HORIZON = size(xit_e1,1);
zzero=zeros(1,HORIZON);
Time_axis = [1:HORIZON];

%MODEL SPECIFIC variables
variable=[1:1:4];

varname1 =   ['nominal interest rate                  34']; 
varname = repmat(varname1(1,:),8,1);
varname(3,:)=['Retail Markup                            '];
varname(1,:)=['Low-efficiency unempl share - log-change '];
varname(4,:)=['Measured matching efficiency             '];
varname(2,:)=['Cutoff productivity l-worker - log-change'];


for counter = 1:1;
for index = 1:size(variable,2);
   newpp=[0.25 , 0.25 , 8, 8];
      grid on
set(gcf,'PaperOrientation','portrait')
set(gcf,'PaperPosition',newpp)
%set(gca,'XTick',[ 4 8 12 16 20])
%set(gca,'XTickLabel',{'1', '2', '3', '4', '5'})
%set(findobj('Type','line'),'LineWidth',2)

%if index ==1 | index==2 | index == 4 | index == 6
   
    subplot(2,2,index),plot(...
        Time_axis,zzero(1,:),':',Time_axis,irf_cali_expansionary(:, 1+1*(index-1)+(counter-1)),'k')
   
xlim([1 HORIZON]);
    grid on
	title(varname(variable(index),:))
 %   set(gca,'XTick',[ 4 8 12 16 20])
%set(gca,'XTickLabel',{'1', '2', '3', '4', '5'})
set(findobj('Type','line'),'LineWidth',1)

		if index == 1
            if counter == 1
ylabel('COVID Scenario')
            elseif counter == 2
			%ylabel('technology shock')
            else
			%ylabel('policy shock')
            end
      end;   
end

figure
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% FIG D /  Kjob, Vacancy-filling probability, vacancies per unemployed, unempl_TFP


load carl200_irf_eu

newpp=[0.25 , 0.25 , 8, 8];
      grid on
set(gcf,'PaperOrientation','portrait')
set(gcf,'PaperPosition',newpp)

HORIZON = size(xit_e1,1);
zzero=zeros(1,HORIZON);
Time_axis = [1:HORIZON];
   
    subplot(2,2,3),plot(...
        Time_axis,zzero(1,:),':',Time_axis,v_e1-s_e1,'k')
   
xlim([1 HORIZON]);
    grid on
	title('Vacancies per unemployed worker')
 %   set(gca,'XTick',[ 4 8 12 16 20])
%set(gca,'XTickLabel',{'1', '2', '3', '4', '5'})
set(findobj('Type','line'),'LineWidth',1)

	
        
subplot(2,2,4),plot(...
        Time_axis,zzero(1,:),':',Time_axis,unempl_TFP,'k')
   
xlim([1 HORIZON]);
    grid on
	title('Average hourly productivity - unemployed')
 %   set(gca,'XTick',[ 4 8 12 16 20])
%set(gca,'XTickLabel',{'1', '2', '3', '4', '5'})
set(findobj('Type','line'),'LineWidth',1)

    
subplot(2,2,1),plot(Time_axis,kjobw_e1,'k',...
        Time_axis,kw_e1,'--k.',Time_axis,kwl_e1,'-.k',Time_axis,zzero(1,:),':')
   
xlim([1 HORIZON]);
    grid on
		legend('unconditional',...
    'high efficiency workers', 'low efficiency workers')
 grid on
 title('Job finding probability')
    %set(gca,'XTick',[ 4 8 12 16 20])
%set(gca,'XTickLabel',{'1', '2', '3', '4', '5'})
set(findobj('Type','line'),'LineWidth',1)
	ylabel('COVID Scenario')

subplot(2,2,2),plot(Time_axis,kjobf_e1,'k',...
        Time_axis,kf_e1,'--k.')
   
xlim([1 HORIZON]);
    grid on
		legend('Probability of productive match',...
    'Probability of interview')
 grid on
 title('Vacancy filling probability')
    %set(gca,'XTick',[ 4 8 12 16 20])
%set(gca,'XTickLabel',{'1', '2', '3', '4', '5'})
set(findobj('Type','line'),'LineWidth',1)
	ylabel('COVID Scenario')
    
figure



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% FIGURE E // 

load carl200_irf % PLANNER
HORIZON = size(xit_e1,1);
zzero=zeros(1,HORIZON);
Time_axis = [1:HORIZON];

irf_cali = [ul_e1*ul_ss, uh_e1*uh_ss, y_e1];

load carl200_irf_eu

irf_cali_expansionary = [ul_e1*ul_ss, uh_e1*uh_ss, y_e1];

   newpp=[0.25 , 0.25 , 8, 8];
      grid on
set(gcf,'PaperOrientation','portrait')
set(gcf,'PaperPosition',newpp)

ul_wedge_cumul = ones(1,10) 
uh_wedge_cumul = ones(1,10)
y_wedge_cumul = ones(1,10)

for count = 1:size(xit_e1,1)
    ul_wedge_cumul(count) = sum(irf_cali_expansionary(1:count,1)-irf_cali(1:count,1))/ul_ss;
    uh_wedge_cumul(count) = sum(irf_cali_expansionary(1:count,2)-irf_cali(1:count,2))/uh_ss;
    y_wedge_cumul(count) = sum(irf_cali_expansionary(1:count,3)-irf_cali(1:count,3));
end


subplot(1,2,1),plot(...
        Time_axis,uh_wedge_cumul,'--k.',Time_axis,ul_wedge_cumul,'-.k',Time_axis,zzero(1,:),':')
   
xlim([1 HORIZON]);
    grid on
		legend(...
    'high efficiency workers', 'low efficiency workers')
 grid on
 title('Cumulative inefficiency Wedge - Unemployment')

 ylabel('COVID Scenario - percent of steady state value')
 
    subplot(1,2,2),plot(Time_axis,-y_wedge_cumul,'k',...
        Time_axis,zzero(1,:),':')
   
xlim([1 HORIZON]);
    grid on
 title('Cumulative inefficiency Wedge - Output')
 
 %   set(gca,'XTick',[ 4 8 12 16 20])
%set(gca,'XTickLabel',{'1', '2', '3', '4', '5'})
set(findobj('Type','line'),'LineWidth',1)

figure

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% FIGURE F NEW// Wedge relative to efficient equilibrium,, gamat, abar, job finding rates 

load carl200_irf % PLANNER
HORIZON = size(xit_e1,1);
zzero=zeros(1,HORIZON);
Time_axis = [1:HORIZON];

irf_cali = [gamat_e1, abar_e1, kw_e1, kwl_e1];

load carl200_irf_eu

irf_cali_expansionary = [gamat_e1, abar_e1, kw_e1, kwl_e1];

   newpp=[0.25 , 0.25 , 8, 8];
      grid on
set(gcf,'PaperOrientation','portrait')
set(gcf,'PaperPosition',newpp)

gamat_wedge = ones(1,10)
abar_wedge = ones(1,10) 
kw_wedge = ones(1,10) 
kwl_wedge = ones(1,10) 

for count = 1:size(xit_e1,1)
    gamat_wedge(count) = irf_cali_expansionary(count,1)-irf_cali(count,1);
    abar_wedge(count) = irf_cali_expansionary(count,2)-irf_cali(count,2);
    kw_wedge(count) = irf_cali_expansionary(count,3)-irf_cali(count,3);
    kwl_wedge(count) = irf_cali_expansionary(count,4)-irf_cali(count,4);
end


subplot(3,1,3),plot(...
        Time_axis,kw_wedge,'--k.',Time_axis,kwl_wedge,'-.k',Time_axis,zzero(1,:),':')
   
xlim([1 HORIZON]);
    grid on
		legend(...
    'high efficiency workers', 'low efficiency workers')
 grid on
 title('Job finding probability wedge')

 ylabel('COVID Scenario')
 
    subplot(3,1,2),plot(Time_axis,gamat_wedge,'k',...
        Time_axis,zzero(1,:),':')
   
xlim([1 HORIZON]);
    grid on
 title('Low-efficiency unemployment share wedge')
 
 %   set(gca,'XTick',[ 4 8 12 16 20])
%set(gca,'XTickLabel',{'1', '2', '3', '4', '5'})
set(findobj('Type','line'),'LineWidth',1)


    subplot(3,1,1),plot(Time_axis,abar_wedge,'k',...
        Time_axis,zzero(1,:),':')
   
xlim([1 HORIZON]);
    grid on
 title('Low-efficiency productivity cutoff wedge')
 
 %   set(gca,'XTick',[ 4 8 12 16 20])
%set(gca,'XTickLabel',{'1', '2', '3', '4', '5'})
set(findobj('Type','line'),'LineWidth',1)
