%Federico Ravenna and Carl Walsh
%"Worker heterogeneity, selection, and employment dynamics in a pandemic"
% Journal of Money, Credit and Banking
%First draft: April 2020
% Current draft: August 2021
%%%%
% SEE README JMCB RAVENNA WALSH 2021.DOC
%%%%

%AMENDED 23 April 2021
clear all
close all

%%%%%%%%%%%%%%%%% NOTE 2021
% carl200_irf >> irf_cali >> benchmark (PLANNER)
% carl200_irf_eu >> irf_cali_expansionary >> MARKET
%%%%%%%%%%%%%%%%%

% Federico Update 7 May 2020
%Produces specific set of plots, for paper
%used to compare baseline vs alternative
%loads data, so can also be used with single baseline experiment
%first needs to use carl200plot_e1_XXXXXX
%
%Built from irf_carl200_dem_persistent.m
%Added at end part of irf_carl200_dem_ZLB.m

% reads the IRF variables generated by Dynare
% listed as : 'variable name in lgy_''name of shock'
% generated by carl200 and carl200_eu

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% FIGURE 1 // FIG A - SHOCKS - ONLY MKT

load carl200_irf_eu
HORIZON = size(xit_e1,1);
zzero=zeros(1,HORIZON);
Time_axis = [1:HORIZON];

irf_cali_expansionary = [y_e1, rhot_e1, d_e1, z_e1 ];

   newpp=[0.25 , 0.25 , 8, 8];
      grid on
set(gcf,'PaperOrientation','portrait')
set(gcf,'PaperPosition',newpp)



%MODEL SPECIFIC variables
variable=[1:1:4];

varname1 =   ['               nominal interest rate ']; 
varname = repmat(varname1(1,:),8,1);
varname(3,:)=['Demand shock                         '];
varname(4,:)=['Separation rate shock                '];
varname(2,:)=['Total separation rate                '];
varname(1,:)=['Output                               '];

for counter = 1:1;
for index = 1:size(variable,2);
   newpp=[0.25 , 0.25 , 8, 8];
      grid on
set(gcf,'PaperOrientation','portrait')
set(gcf,'PaperPosition',newpp)
%set(gca,'XTick',[ 4 8 12 16 20])
%set(gca,'XTickLabel',{'1', '2', '3', '4', '5'})
%set(findobj('Type','line'),'LineWidth',2)

%if index ==1 | index==2 | index == 3 
   
    subplot(2,2,index),plot(...
                Time_axis,zzero(1,:),':',Time_axis,irf_cali_expansionary(:, 1+1*(index-1)+(counter-1)),'k')
        
   
xlim([1 HORIZON]);
    grid on
	title(varname(variable(index),:))
 %   set(gca,'XTick',[ 4 8 12 16 20])
%set(gca,'XTickLabel',{'1', '2', '3', '4', '5'})
set(findobj('Type','line'),'LineWidth',1)

		if index == 1
            if counter == 1
ylabel('COVID Scenario')
            elseif counter == 2
			%ylabel('technology shock')
            else
			%ylabel('policy shock')
            end
      end;
       if index == 3,
          xlabel(['']);	%second rule
		elseif index ==4,
         xlabel(['']); %first rule
       
       else,
		end;	
       
%else
    
%end
end

figure
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% FIGURE 2bis - FIG B BIS Unempl rate, PP from ss (subtract ss)
%%%%% COLOR AREA so areas sum

load carl200_irf_eu
HORIZON = size(xit_e1,1);
zzero=zeros(1,HORIZON);
Time_axis = [1:HORIZON];

share_nl = nl_e1*nl_ss./(n_e1*n_ss)*100;
share_nh = nh_e1*nh_ss./(n_e1*n_ss)*100;
share_scaled_ul = share_nl.*(unempl-u_ss*100)/100
share_scaled_uh = share_nh.*(unempl-u_ss*100)/100

   newpp=[0.25 , 0.25 , 8, 8];
      grid on
set(gcf,'PaperOrientation','portrait')
set(gcf,'PaperPosition',newpp)

newpp=[0.25 , 0.25 , 8, 8];
      grid on
set(gcf,'PaperOrientation','portrait')
set(gcf,'PaperPosition',newpp)
%set(gca,'XTick',[ 4 8 12 16 20])
%set(gca,'XTickLabel',{'1', '2', '3', '4', '5'})
%set(findobj('Type','line'),'LineWidth',2)

    subplot(1,2,1),plot(Time_axis,u_e1*u_ss,'k',...
        Time_axis,uh_e1*uh_ss,'--k.',Time_axis,ul_e1*ul_ss,'-.k',Time_axis,zzero(1,:),':')
   
xlim([1 HORIZON]);
    grid on
		legend('total',...
    'high efficiency workers', 'low efficiency workers')
 grid on
 title('Unemployment Rate - log-change ')

 ylabel('COVID Scenario')
 
    %subplot(1,2,2),plot(Time_axis,u_e1*u_ss,'k',...
    subplot(1,2,2),plot(Time_axis,share_scaled_ul,'k',...
        Time_axis,share_scaled_uh,'--k.', Time_axis,zzero(1,:),':')
   
xlim([1 HORIZON]);
    grid on
		legend('total',...
    'high efficiency workers')
 grid on
 title('Unemployment shares')
 
 %   set(gca,'XTick',[ 4 8 12 16 20])
%set(gca,'XTickLabel',{'1', '2', '3', '4', '5'})
set(findobj('Type','line'),'LineWidth',1)
