%AMENDED 23 April 2021
%Federico Ravenna and Carl Walsh
%"Worker heterogeneity, selection, and employment dynamics in a pandemic"
% Journal of Money, Credit and Banking
%First draft: April 2020
% Current draft: August 2021
%%%%
% SEE README JMCB RAVENNA WALSH 2021.DOC
%%%%

clear all
close all

%%%%%%%%%%%%%%%%% NOTE 2021
% carl200_irf >> irf_cali >> benchmark (PLANNER)
% carl200_irf_eu >> irf_cali_expansionary >> MARKET
%%%%%%%%%%%%%%%%%

% Federico Update 7 May 2020
%Produces specific set of plots, for paper
%used to compare baseline vs alternative
%loads data, so can also be used with single baseline experiment
%first needs to use carl200plot_e1_XXXXXX
%
%Built from irf_carl200_dem_persistent.m
%Added at end part of irf_carl200_dem_ZLB.m

% reads the IRF variables generated by Dynare
% listed as : 'variable name in lgy_''name of shock'
% generated by carl200 and carl200_eu

%%% FIGURE A  TEMP (NEW: with unemployment share
load carl200_irf % TEMP
HORIZON = size(xit_e1,1);
zzero=zeros(1,HORIZON);
Time_axis = [1:HORIZON];

share_nl = nl_e1*nl_ss./(n_e1*n_ss)*100;
share_nh = nh_e1*nh_ss./(n_e1*n_ss)*100;
share_scaled_ul = share_nl.*(u_e1*u_ss)/100;
share_scaled_uh = share_nh.*(u_e1*u_ss)/100;

irf_cali = [s_e1, sh_e1, sl_e1, share_scaled_ul, share_scaled_uh, zzero', th_e1, kfl_e1, kw_e1, kwl_e1 ];
%irf_cali = [s_e1, sh_e1, sl_e1, u_e1*u_ss, share_scaled_uh, zzero', th_e1, kfl_e1, kw_e1, kwl_e1 ];

load carl200_irf_eu

share_nl = nl_e1*nl_ss./(n_e1*n_ss)*100;
share_nh = nh_e1*nh_ss./(n_e1*n_ss)*100;
share_scaled_ul = share_nl.*(u_e1*u_ss)/100;
share_scaled_uh = share_nh.*(u_e1*u_ss)/100;

%irf_cali_expansionary = [s_e1, sh_e1, sl_e1, u_e1*u_ss, share_scaled_uh, zzero', th_e1, kfl_e1, kw_e1, kwl_e1 ];
irf_cali_expansionary = [s_e1, sh_e1, sl_e1, share_scaled_ul, share_scaled_uh, zzero', th_e1, kfl_e1, kw_e1, kwl_e1 ];

irf_cali_diff = irf_cali-irf_cali_expansionary;

   newpp=[0.25 , 0.25 , 8, 8];
      grid on
set(gcf,'PaperOrientation','portrait')
set(gcf,'PaperPosition',newpp)

variable=[1:1:4];

varname1 =   ['               nominal interest rate ']; 
varname = repmat(varname1(1,:),8,1);
varname(3,:)=['vacancies and hiring                 '];
varname(4,:)=['Job finding probability              '];
varname(2,:)=['Unemployment shares                  '];
varname(1,:)=['Job seekers                          '];


for index = 1:size(variable,2);
   newpp=[0.25 , 0.25 , 8, 8];
      grid on
set(gcf,'PaperOrientation','portrait')
set(gcf,'PaperPosition',newpp)

if index ==1 
   
    subplot(2,2,index),plot(...
                Time_axis,irf_cali_diff(:, 1+3*(index-1)),'k'...
                ,Time_axis,irf_cali_diff(:, 2+3*(index-1)),'--k'...
                ,Time_axis,irf_cali_diff(:, 3+3*(index-1)),':k')
        
   
xlim([1 HORIZON]);
    grid on
	title(varname(variable(index),:))
 %   set(gca,'XTick',[ 4 8 12 16 20])
%set(gca,'XTickLabel',{'1', '2', '3', '4', '5'})
set(findobj('Type','line'),'LineWidth',1)
legend('total','type h', 'type l')

		if index == 1
            ylabel('TEMP LAYOFF')
            else
        end
      
elseif index ==2
    
         subplot(2,2,index),plot(...
                Time_axis,irf_cali_diff(:, 1+3*(index-1)),'k'...
                ,Time_axis,irf_cali_diff(:, 2+3*(index-1)),'--k')
            xlim([1 HORIZON]);
    grid on
	title(varname(variable(index),:))
 %   set(gca,'XTick',[ 4 8 12 16 20])
%set(gca,'XTickLabel',{'1', '2', '3', '4', '5'})
set(findobj('Type','line'),'LineWidth',1)

elseif index == 3,
               subplot(2,2,index),plot(...
                Time_axis,irf_cali_diff(:, 1+3*(index-1)),'k'...
                ,Time_axis,irf_cali_diff(:, 2+3*(index-1)),'--k')
            xlim([1 HORIZON]);
    grid on
	title(varname(variable(index),:))
 %   set(gca,'XTick',[ 4 8 12 16 20])
%set(gca,'XTickLabel',{'1', '2', '3', '4', '5'})
set(findobj('Type','line'),'LineWidth',1)
legend('\theta','prob. hiring type l')
		elseif index ==4,
            subplot(2,2,index),plot(...
                Time_axis,irf_cali_diff(:, 0+3*(index-1)),'k'...
                ,Time_axis,irf_cali_diff(:, 1+3*(index-1)),'--k')
            xlim([1 HORIZON]);
    grid on
	title(varname(variable(index),:))
 %   set(gca,'XTick',[ 4 8 12 16 20])
%set(gca,'XTickLabel',{'1', '2', '3', '4', '5'})
set(findobj('Type','line'),'LineWidth',1)
legend('type h','type l')
                
       else,
		end;	
       end

