% MODIFIED JUNE 20 to work with carl202zlb_cond2.mod

% Federico Update May 7
%$carl200plot_e1_cond2020.m [CONDITIONAL FORECAST]
%Produces specific set of variables and plots, for paper
%run to produce several variables, once saved, they are read
%to produce final plots with irf_carl200_dem_2020.m
%Used to produce variables for comparison of experiments
%performed in irf_carl200_dem_2020.m

% shift to account for new variables in carl202zlb_cond2.mod
shift = 4;

n_ss = exp(oo_.steady_state(22+shift));
ul_ss = exp(oo_.steady_state(25+shift));
uh_ss = exp(oo_.steady_state(24+shift));
u_ss = exp(oo_.steady_state(26+shift));
nh_ss = exp(oo_.steady_state(20+shift));
nl_ss = exp(oo_.steady_state(21+shift));
v_ss = exp(oo_.steady_state(15+shift));
x_ss = exp(oo_.steady_state(44+shift));
surph_ss = exp(oo_.steady_state(41+shift));

% translate all needed variables
clear varname
varstart=1;
periods = size(oo_.conditional_forecast.cond.Mean.y,1);

for i=1:M_.endo_nbr;
    %for i=varstart:varend; produces cond_data, to feed to MAKECHART, and 
    % varname, to feed to makechart. Order in oo_.conditional_forecast.cond.Mean
    % DOES NOT need to be  same as order in M_.endo_names:
    % EVAL instruction takes care of reading the forecast path with same
    % name as taken from M_.endo_names. 
    %Then subtract ss value. This does not need an EVAL instruction since
    %order of oo_.steady_state is same as order of M_.endo_names
    Mendonames = deblank(M_.endo_names{i,:}); 
    varname1=char(Mendonames);
     if i == varstart
        varname = char(varname1);    
     else
        varname = char(varname,varname1); %concatenates vertically //to concatenate horizontally:? aa ={aa,aa1};
     end
eval([ Mendonames,'_e1=oo_.conditional_forecast.cond.Mean.',Mendonames,'-oo_.steady_state(i);']);
eval([Mendonames,'_e1=',Mendonames,'_e1(2:periods,:);']);     
%eval(['cond_data(:,i-varstart+1)=oo_.conditional_forecast.cond.Mean.',Mendonames,';']);
    %cond_data(:,i-varstart+1) = cond_data(:,i-varstart+1)-oo_.steady_state(i);
end
clear varstart

maximum =size(u_e1,1);
t=(1:1:maximum);
unempl = (u_e1)*(1-n_ss);
unempl_l = (ul_e1)*ul_ss;
unempl_h = (uh_e1)*uh_ss;
empl = (n_e1)*(n_ss);
empl_l = (nl_e1)*nl_ss;
empl_h = (nh_e1)*nh_ss;
figure
subplot(2,2,1), plot(t,unempl)
xlabel('percentage points change unempl rate')
grid on
subplot(2,2,2), plot(t,empl)
xlabel('percentage points change EMPL rate')
grid on

subplot(2,2,3), plot(t,u_e1)
xlabel('%dev SS unempl rate')
grid off
subplot(2,2,4), plot(t,n_e1)
xlabel('%dev SS EMPL rate')


figure
subplot(4,2,1), plot(t,unempl_l)
xlabel('percentage points change unempl rate L')
title('EMPL rate computed as share of TOTAL labor force. 1-UNEMPL computes as share of OWN labor force')
grid on
subplot(4,2,3), plot(t,unempl_h)
xlabel('percentage points change unempl rate H')
grid on
subplot(4,2,5), plot(t,ul_e1)
xlabel('%dev SS unempl rate L')
%grid off
subplot(4,2,7), plot(t,uh_e1)
xlabel('%dev SS unempl rate H')
%grid off


subplot(4,2,2), plot(t,empl_l)
xlabel('percentage points change EMPL rate L')
grid on
subplot(4,2,4), plot(t,empl_h)
xlabel('percentage points change EMPL rate H')
grid on
subplot(4,2,6), plot(t,nl_e1)
xlabel('%dev SS EMPL rate L')
subplot(4,2,8), plot(t,nh_e1)
xlabel('%dev SS EMPL rate H')

u_rate = (unempl/100+u_ss)*100;
v_rate = ((v_e1*v_ss)/100+v_ss)*100;
uh_rate = (unempl_h/100+uh_ss)*100;
vh_rate = ((v_e1*v_ss)/100+v_ss)*100/(1-gamabar);
ul_rate = (unempl_l/100+ul_ss)*100;
vl_rate = ((v_e1*v_ss)/100+v_ss)*100/(gamabar);

figure
plot(u_rate,v_rate)
title('Beveridge curve, aggregate')
figure
%plot(uh_rate,vh_rate)
plot(uh_rate,v_rate)
title('Beveridge curve, H workers')
figure
%plot(ul_rate,vl_rate)
plot(ul_rate,v_rate)
title('Beveridge curve, L workers')

figure 
plot((((surph_e1*surph_ss)+surph_ss-((x_e1*x_ss)+x_ss)))*100/(surph_ss-x_ss))
grid on
title('surplus difference between H and L skilled worker in % of steady state difference')

figure
 plot(0*kw_e1+rhon_e1,'.')
 hold on
 grid on
 plot(gamat_e1+0*kw_e1+rhon_e1) 
title('screening rate, with (SOLID) and without composition effect')
hold off

figure
hold on
plot(kjobw_e1)
 plot(kw_e1,'.')
 plot(kwl_e1,'-.')

 legend('unconditional',...
    'high-skill', 'low skill')
 grid on
 title('job finding probability log-change')

 
% figure
% hold on
%  plot(kjobw_e1*kjobw_ss/100+kjobw_ss)
% plot(kw_e1*kw_ss/100+kw_ss,'.')
% plot(kwl_e1*kwl_ss/100+kwl_ss,'-.')
 %title('job finding probability - levels')

 %carl200table

% Building some variables used in irf_carl200_tech_nocomposition.m
%log change in kjobw

%kjobw_rebuilt = ...
%    (1/(1-exp(dr_.ys(6))*exp(dr_.ys(33))))*...
%    (-(exp(dr_.ys(6))*exp(dr_.ys(33)))*(rhon_e1+gamat_e1))+kw_e1;

%contribution_rhon = -(exp(dr_.ys(6))*exp(dr_.ys(33)))*(rhon_e1)./kjobw_e1*(1/(1-exp(dr_.ys(6))*exp(dr_.ys(33))))*100
%contribution_gamat = -(exp(dr_.ys(6))*exp(dr_.ys(33)))*(gamat_e1)./kjobw_e1*(1/(1-exp(dr_.ys(6))*exp(dr_.ys(33))))*100
%contribution_kw = kw_e1./kjobw_e1*100

%display('period by period and cumulative share of log-change in kjobw (outflow rate)')
%display('given by log-change in variable')

%cum_contribution_rhon = -(exp(dr_.ys(6))*exp(dr_.ys(33)))*(sum(rhon_e1))/sum(kjobw_e1)*(1/(1-exp(dr_.ys(6))*exp(dr_.ys(33))))*100
%cum_contribution_gamat = -(exp(dr_.ys(6))*exp(dr_.ys(33)))*(sum(gamat_e1))/sum(kjobw_e1)*(1/(1-exp(dr_.ys(6))*exp(dr_.ys(33))))*100
%cum_contribution_kw = sum(kw_e1)/sum(kjobw_e1)*100

%%%%%%%%%%%%%
%log-change in vacancies per unemployed worker v-s
G_SS = exp(oo_.steady_state(16+shift))*(1-exp(oo_.steady_state(30+shift)))*exp(oo_.steady_state(44+shift))+(1-exp(oo_.steady_state(16+shift)))*exp(oo_.steady_state(41+shift));
%v_minus_s_rebuilt = (1/G_SS)*(1/alpha)*(...
%    exp(dr_.ys(6))*(1-exp(dr_.ys(33)))*exp(dr_.ys(48))*gamat_e1...
%    -exp(dr_.ys(6))*(exp(dr_.ys(33)))*exp(dr_.ys(48))*rhon_e1...
%    +exp(dr_.ys(6))*(1-exp(dr_.ys(33)))*exp(dr_.ys(48))*x_e1...
%    -exp(dr_.ys(6))*exp(dr_.ys(39))*gamat_e1...
%    +(1-exp(dr_.ys(6)))*exp(dr_.ys(39))*surph_e1)

display('period by period counterfactual of log-change in vacancies per unemployed')
display('worker if gamat does not change in a recession')

v_minus_s_no_gamat = (1/G_SS)*(1/alpha)*(...
    exp(oo_.steady_state(16+shift))*(1-exp(oo_.steady_state(30+shift)))*exp(oo_.steady_state(44+shift))*0*gamat_e1...
    -exp(oo_.steady_state(16+shift))*(exp(oo_.steady_state(30+shift)))*exp(oo_.steady_state(44+shift))*rhon_e1...
    +exp(oo_.steady_state(16+shift))*(1-exp(oo_.steady_state(30+shift)))*exp(oo_.steady_state(44+shift))*x_e1...
    -exp(oo_.steady_state(16+shift))*exp(oo_.steady_state(41+shift))*0*gamat_e1...
    +(1-exp(oo_.steady_state(16+shift)))*exp(oo_.steady_state(41+shift))*surph_e1)
    

    
%%% TFP with and without composition effect

% ss TFP of unemployed
% note that we measure TFP of unemployed at the moment they are available
% for work. Their productivity is equal to the one of the labor force since
% the idiosyncratic productivity is match-specific 

rhon_ss = exp(oo_.steady_state(30+shift))
gamat_ss = exp(oo_.steady_state(16+shift))
%pause
xit_ss = exp(oo_.steady_state(17+shift))

ss =(zl_ss/2*gamat_ss*(1)+zh_ss*(1-gamat_ss*(1)))*1
unempl_TFP = (((zl_ss/2*gamat_ss*(1+gamat_e1/100)+zh_ss*(1-gamat_ss*(1+gamat_e1/100))).*(1+0)-ss)/ss)*100;  %.*(1+z_e1/100)-ss)/ss)*100;
lf_TFP = 0*d_e1

%lskill_TFP = z_e1;
%hskill_TFP = z_e1+d_e1;
%$unempl_TFP = ((zl_ss/2*gamat_ss*(1+gamat_e1/100).*(1+z_e1/100))+zh_ss*(1-gamat_ss*(1+gamat_e1/100)).*(1+(z_e1+d_e1)/100)-ss)/ss*100

% ss TFP of EMployed
% note that EMPLOYED low skill are only low skill workers which have 
% not been screened outw

ss_low_skill_employed_hourly_productivity = zl_ss*(1/(1-rhon_ss))*(1/2-rhon_ss^2/2)
ss_employed_hourly_productivity = (zl_ss*(1/(1-rhon_ss))*(1/2-rhon_ss^2/2)*xit_ss*(1)+zh_ss*(1-xit_ss*(1)))*1

% Hours per worker

ss_hours = (1-exp(oo_.steady_state(17+shift)))*exp(oo_.steady_state(40+shift))...
    +exp(oo_.steady_state(17+shift))*exp(oo_.steady_state(10+shift));

ho_ss = exp(oo_.steady_state(40+shift));
holav_ss = exp(oo_.steady_state(10+shift));

hours = ((ho_ss*(1+ho_e1/100).*(1-xit_ss*(1+xit_e1/100))    +holav_ss*(1+holav_e1/100).*(xit_ss*(1+xit_e1/100)))...
    -ss_hours)*100/ss_hours;

%%%%%%%%%%
%Sacrifice ratios: ratios between cumulative IRF of various variables
%to compare the change in employment per 1% change in output
%across persistent and less persistent fall in demand
%sum over 40 periods (20 or 40 Irrelevant for rhom=0.75 case)

%EU Calibration
%Basic policy rule

display('Sacrifice ratio')

sum(n_e1)/sum(y_e1)
sum(n_e1)/sum(d_e1)
sum(unempl_TFP)/sum(d_e1)

%%% ADDED MAY 2020

%Vacancies
v_rate_difference = ((v_e1*100*v_ss)/100+v_ss);
v_rate_1_difference = (((v_e1-n_e1)*100*(v_ss/n_ss))/100+(v_ss/n_ss));

%%%% WAGE
 % data used only for great recession shock
    aa_ss = surph_ss*(1-xit_ss);
    bb_ss = xit_ss*x_ss;
    gg_ss = aa_ss+bb_ss;
    wage_difference = (1/gg_ss)*(aa_ss*surph_e1-surph_ss*xit_ss*xit_e1+bb_ss*(x_e1+xit_e1));
    
    %HOURLY WAGES
    wage_hourly_difference = wage_difference-hours;
    
    wage_hourly_difference_h = surph_e1 - ho_e1;
    wage_hourly_difference_l = x_e1 - holav_e1;
    
    %TOTAL WAGES
    wage_tot_difference = wage_difference;%-hours;
    
    wage_tot_difference_h = surph_e1;% - ho_e1;
    wage_tot_difference_l = x_e1; %- holav_e1;
    
    
    
    alp_hourly_difference = y_e1-n_e1-hours;
    %alp only for TFP shock = z_ss
    h_difference = h_e1;
    v_difference = v_e1;
    s_difference = s_e1;
    unempl_difference = unempl;
