clear all
close all
%Federico Ravenna and Carl Walsh
%"Worker heterogeneity, selection, and employment dynamics in a pandemic"
% Journal of Money, Credit and Banking
%First draft: April 2020
% Current draft: August 2021
%%%%
% SEE README JMCB RAVENNA WALSH 2021.DOC
%%%%


%UPDATED 31 JULY 2021 Final JMCB Resubmission
% Federico Update 7 May 2020
%Produces specific set of plots, for paper
%used to compare baseline vs alternative
%loads data, so can also be used with single baseline experiment
%first needs to use carl200plot_e1_XXXXXX
%
%Built from irf_carl200_dem_persistent.m
%Added at end part of irf_carl200_dem_ZLB.m

% reads the IRF variables generated by Dynare
% listed as : 'variable name in lgy_''name of shock'
% generated by carl200 and carl200_eu


% BENCHMARK: std IT, policy_bbench // DOTTED
dotted = ['Policy (2): Respond to inflation (benchmark)'] 
% POLICY A: Expansionary omegay*N,omegay=0.4 policy_aa //DASHED
dashed = ['Policy (3): Respond to unemployment \omega_{u}=0.4'] 
% POLICY B: Expansionary omegay*N,omegay=0.8 policy_bb //dashedDOTTED
dasheddotted = ['Policy (4): Respond to unemployment \omega_{u}=0.8'] 
% POLICY A0: STRICT IT, policy_a0 //SOLID
solid = ['Policy (1): Price stability'] 
% POLICY RHON: react to layoff rate // diamond
diamonds = ['Policy (5): Respond to separation rate']
% POLICY N: stabilize unemployment at ss 'policy_ntarget'// squares
squares = ['Policy targeting zero-unemployment']


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% FIGURE 1POLICY - Unempl rate, PP from ss (subtract ss), and UNEMP SHARE
%%% l-WORKERS
%%%%% COLOR AREA so areas sum
u_initial = 5.9491

%%%% START price stability policy
load policy_a0
HORIZON = size(xit_e1,1);
zzero=zeros(1,HORIZON);
Time_axis = [1:HORIZON];

share_nl = nl_e1*nl_ss./(n_e1*n_ss)*100;
share_nh = nh_e1*nh_ss./(n_e1*n_ss)*100;
share_scaled_ul = share_nl.*(u_e1*u_ss)/100;
share_scaled_uh = share_nh.*(u_e1*u_ss)/100;

irf_policy_a0 = [unempl_l, unempl_h, Pi_e1, rn_e1, unempl, rhon_e1 ];

u_diff = [];
u_d_cumul = [];
ineq_ratio = [];
symm_infl_cost = [];

ul_cumul = ones(1,10) ;
uh_cumul = ones(1,10);
y_cumul = ones(1,10);
Pi_cumul =  ones(1,10);
Pi_cumul(1)=nan;

for count = 1:size(xit_e1,1)
    ul_cumul(count) = sum(share_scaled_ul(1:count,1));
    uh_cumul(count) = sum(share_scaled_uh(1:count,1));
    y_cumul(count) = sum(y_e1(1:count,1));
    ineq_ratio(count) = ul_cumul(count)/uh_cumul(count);
end

u_diff = unempl(2:size(xit_e1,1)) - u_initial;
u_diff = [0; u_diff];
for count = 1:size(xit_e1,1)
    Pi_cumul(count) = sum(abs(Pi_e1(2:count,1)));
    u_d_cumul(count) = sum(u_diff(1:count,1));
end

u_d_cumul(1) = nan;
u_diff(1) = nan;
Pi_cumul(1)=nan;
symm_infl_cost_cumul = Pi_cumul./u_d_cumul;
symm_infl_cost = Pi_cumul'./u_diff;

display('policy a0') 
display('sac ratio // sac ratio CUMUL //  ineq ratio // cumul y // cumul ul_share // cumul uh_share')
policy_matrix = [-symm_infl_cost(8), -symm_infl_cost_cumul(8), ineq_ratio(8), y_cumul(8), ul_cumul(8), uh_cumul(8)]

%%%% for Marginal Sac Ratio
unempl_a0 = unempl;
Pi_a0 = Pi_e1;
%%%%

%%%%%%%%%%%%% END PRICE STABILITY

%%% RHON Policy 
load policy_rhon
HORIZON = size(xit_e1,1);
zzero=zeros(1,HORIZON);
Time_axis = [1:HORIZON];

share_nl = nl_e1*nl_ss./(n_e1*n_ss)*100;
share_nh = nh_e1*nh_ss./(n_e1*n_ss)*100;
share_scaled_ul = share_nl.*(u_e1*u_ss)/100;
share_scaled_uh = share_nh.*(u_e1*u_ss)/100;

irf_policy_rhon = [unempl_l, unempl_h, Pi_e1, rn_e1, unempl,  rhon_e1 ];

u_diff = [];
u_d_cumul = [];
ineq_ratio = [];
symm_infl_cost = [];

ul_cumul = ones(1,10) ;
uh_cumul = ones(1,10);
y_cumul = ones(1,10);
Pi_cumul =  ones(1,10);
Pi_cumul(1)=nan;

for count = 1:size(xit_e1,1)
    ul_cumul(count) = sum(share_scaled_ul(1:count,1));
    uh_cumul(count) = sum(share_scaled_uh(1:count,1));
    y_cumul(count) = sum(y_e1(1:count,1));
    ineq_ratio(count) = ul_cumul(count)/uh_cumul(count);
end

u_diff = unempl(2:size(xit_e1,1)) - u_initial;
u_diff = [0; u_diff];
for count = 1:size(xit_e1,1)
    Pi_cumul(count) = sum(abs(Pi_e1(2:count,1)));
    u_d_cumul(count) = sum(u_diff(1:count,1));
end

u_d_cumul(1) = nan;
u_diff(1) = nan;
Pi_cumul(1)=nan;
symm_infl_cost_cumul = Pi_cumul./u_d_cumul;
symm_infl_cost = Pi_cumul'./u_diff;

display('policy rhon') 
display('sac ratio // sac ratio CUMUL //  ineq ratio // cumul y // cumul ul_share // cumul uh_share')
policy_matrix = [-symm_infl_cost(8), -symm_infl_cost_cumul(8), ineq_ratio(8), y_cumul(8), ul_cumul(8), uh_cumul(8)]

%%%% for Marginal Sac Ratio
Pi_diff_m = Pi_e1 - Pi_a0;
unempl_diff_m = unempl - unempl_a0;

for count = 1:size(xit_e1,1)
    Pi_cumul_m(count) = sum(Pi_diff_m(1:count,1));
    unempl_cumul_m(count) = sum(unempl_diff_m(1:count,1));
end

sac_ratio_m = Pi_cumul_m./unempl_cumul_m;
sac_ratio_m'

display('marginal sac ratio CUMUL policy rhon / layoff rate relative to price stability (A0)')
policy_matrix2 = [-sac_ratio_m(8)]
pause
%%%%
%%%%% END RHON POLICY

load policy_bbench
HORIZON = size(xit_e1,1);
zzero=zeros(1,HORIZON);
Time_axis = [1:HORIZON];

share_nl = nl_e1*nl_ss./(n_e1*n_ss)*100;
share_nh = nh_e1*nh_ss./(n_e1*n_ss)*100;
share_scaled_ul = share_nl.*(u_e1*u_ss)/100
share_scaled_uh = share_nh.*(u_e1*u_ss)/100

irf_policy_bbench = [unempl_l, unempl_h, Pi_e1, rn_e1, unempl, rhot_e1 ];

u_diff = [];
u_d_cumul = [];
ineq_ratio = [];
symm_infl_cost = [];

ul_cumul = ones(1,10) ;
uh_cumul = ones(1,10);
y_cumul = ones(1,10);
Pi_cumul =  ones(1,10);
Pi_cumul(1)=nan;

for count = 1:size(xit_e1,1)
    ul_cumul(count) = sum(share_scaled_ul(1:count,1));
    uh_cumul(count) = sum(share_scaled_uh(1:count,1));
    y_cumul(count) = sum(y_e1(1:count,1));
    ineq_ratio(count) = ul_cumul(count)/uh_cumul(count);
end

display('initial level unemployment for sacrifice ratio')
u_initial = 5.9491
pause

u_diff = unempl(2:size(xit_e1,1)) - u_initial;
u_diff = [0; u_diff];
for count = 1:size(xit_e1,1)
    Pi_cumul(count) = sum(abs(Pi_e1(2:count,1)));
    u_d_cumul(count) = sum(u_diff(1:count,1));
end

u_d_cumul(1) = nan;
u_diff(1) = nan;
Pi_cumul(1)=nan;
symm_infl_cost_cumul = Pi_cumul./u_d_cumul;
symm_infl_cost = Pi_cumul'./u_diff;

display('policy bbench') 
display('sac ratio // sac ratio CUMUL //  ineq ratio // cumul y // cumul ul_share // cumul uh_share')
policy_matrix = [-symm_infl_cost(8), -symm_infl_cost_cumul(8), ineq_ratio(8), y_cumul(8), ul_cumul(8), uh_cumul(8)]
pause

unempl_bbench = unempl;
Pi_bbench = Pi_e1;

load policy_bb
HORIZON = size(xit_e1,1);
zzero=zeros(1,HORIZON);
Time_axis = [1:HORIZON];

share_nl = nl_e1*nl_ss./(n_e1*n_ss)*100;
share_nh = nh_e1*nh_ss./(n_e1*n_ss)*100;
share_scaled_ul = share_nl.*(u_e1*u_ss)/100;
share_scaled_uh = share_nh.*(u_e1*u_ss)/100;

irf_policy_bb = [unempl_l, unempl_h, Pi_e1, rn_e1, unempl, rhon_e1 ];

u_diff = [];
u_d_cumul = [];
ineq_ratio = [];
symm_infl_cost = [];

ul_cumul = ones(1,10) ;
uh_cumul = ones(1,10);
y_cumul = ones(1,10);
Pi_cumul =  ones(1,10);
Pi_cumul(1)=nan;

for count = 1:size(xit_e1,1)
    ul_cumul(count) = sum(share_scaled_ul(1:count,1));
    uh_cumul(count) = sum(share_scaled_uh(1:count,1));
    y_cumul(count) = sum(y_e1(1:count,1));
    ineq_ratio(count) = ul_cumul(count)/uh_cumul(count);
end

u_diff = unempl(2:size(xit_e1,1)) - u_initial;
u_diff = [0; u_diff];
for count = 1:size(xit_e1,1)
    Pi_cumul(count) = sum(abs(Pi_e1(2:count,1)));
    u_d_cumul(count) = sum(u_diff(1:count,1));
end

u_d_cumul(1) = nan;
u_diff(1) = nan;
Pi_cumul(1)=nan;
symm_infl_cost_cumul = Pi_cumul./u_d_cumul;
symm_infl_cost = Pi_cumul'./u_diff;

display('policy bb') 
display('sac ratio // sac ratio CUMUL //  ineq ratio // cumul y // cumul ul_share // cumul uh_share')
policy_matrix = [-symm_infl_cost(8), -symm_infl_cost_cumul(8), ineq_ratio(8), y_cumul(8), ul_cumul(8), uh_cumul(8)]

%%%% for Marginal Sac Ratio
unempl_bb = unempl;
Pi_bb = Pi_e1;
%%%%
pause


load policy_aa
HORIZON = size(xit_e1,1);
zzero=zeros(1,HORIZON);
Time_axis = [1:HORIZON];

share_nl = nl_e1*nl_ss./(n_e1*n_ss)*100;
share_nh = nh_e1*nh_ss./(n_e1*n_ss)*100;
share_scaled_ul = share_nl.*(u_e1*u_ss)/100;
share_scaled_uh = share_nh.*(u_e1*u_ss)/100;

irf_policy_aa = [unempl_l, unempl_h, Pi_e1, rn_e1, unempl ];

u_diff = [];
u_d_cumul = [];
ineq_ratio = [];
symm_infl_cost = [];

ul_cumul = ones(1,10) ;
uh_cumul = ones(1,10);
y_cumul = ones(1,10);
Pi_cumul =  ones(1,10);
Pi_cumul(1)=nan;

for count = 1:size(xit_e1,1)
    ul_cumul(count) = sum(share_scaled_ul(1:count,1));
    uh_cumul(count) = sum(share_scaled_uh(1:count,1));
    y_cumul(count) = sum(y_e1(1:count,1));
    ineq_ratio(count) = ul_cumul(count)/uh_cumul(count);
end

u_diff = unempl(2:size(xit_e1,1)) - u_initial;
u_diff = [0; u_diff];
for count = 1:size(xit_e1,1)
    Pi_cumul(count) = sum(abs(Pi_e1(2:count,1)));
    u_d_cumul(count) = sum(u_diff(1:count,1));
end

u_d_cumul(1) = nan;
u_diff(1) = nan;
Pi_cumul(1)=nan;
symm_infl_cost_cumul = Pi_cumul./u_d_cumul;
symm_infl_cost = Pi_cumul'./u_diff;

display('policy aa') 
display('sac ratio // sac ratio CUMUL //  ineq ratio // cumul y // cumul ul_share // cumul uh_share')
policy_matrix = [-symm_infl_cost(8), -symm_infl_cost_cumul(8), ineq_ratio(8), y_cumul(8), ul_cumul(8), uh_cumul(8)]

%%%%
Pi_diff_m = Pi_e1-Pi_a0;
unempl_diff_m = unempl - unempl_a0;


for count = 1:size(xit_e1,1)
    Pi_cumul_m(count) = sum(Pi_diff_m(1:count,1));
    unempl_cumul_m(count) = sum(unempl_diff_m(1:count,1));
end

sac_ratio_m = Pi_cumul_m./unempl_cumul_m;
%sac_ratio_m'

display('marginal sac ratio CUMUL policy AA (omegau=0.4)relative to PRICE STABILITY')
policy_matrix2 = [-sac_ratio_m(8)]
%%%%
pause
%%%%
%Pi_diff_m = Pi_bb - Pi_e1;
%unempl_diff_m = unempl_bb - unempl;

Pi_diff_m = Pi_bb - Pi_a0;
unempl_diff_m = unempl_bb - unempl_a0;


for count = 1:size(xit_e1,1)
    Pi_cumul_m(count) = sum(Pi_diff_m(1:count,1));
    unempl_cumul_m(count) = sum(unempl_diff_m(1:count,1));
end

sac_ratio_m = Pi_cumul_m./unempl_cumul_m;
sac_ratio_m'

display('marginal sac ratio CUMUL policy BB (omegau=0.8) relative to price stability (A0)')
policy_matrix2 = [-sac_ratio_m(8)]
%%%%

pause

   newpp=[0.25 , 0.25 , 8, 8];
      grid on
set(gcf,'PaperOrientation','portrait')
set(gcf,'PaperPosition',newpp)

newpp=[0.25 , 0.25 , 8, 8];
      grid on
set(gcf,'PaperOrientation','portrait')
set(gcf,'PaperPosition',newpp)
%set(gca,'XTick',[ 4 8 12 16 20])
%set(gca,'XTickLabel',{'1', '2', '3', '4', '5'})
%set(findobj('Type','line'),'LineWidth',2)

    subplot(3,2,3),plot(Time_axis,irf_policy_a0(:,1),'-ko',Time_axis,irf_policy_bbench(:,1),':k',...
        Time_axis,irf_policy_aa(:,1),'--k.',Time_axis,irf_policy_bb(:,1),'-.k')
   
xlim([1 HORIZON]);
    grid on
		legend(solid, dotted, dashed, dasheddotted)
 grid on
 title('Unemployment rate l-workers ')
 
 subplot(3,2,4),plot(Time_axis,irf_policy_a0(:,2),'-ko',Time_axis,irf_policy_bbench(:,2),':k',...
        Time_axis,irf_policy_aa(:,2),'--k.',Time_axis,irf_policy_bb(:,2),'-.k')
    
   xlim([1 HORIZON]);
    grid on
		
 title('Unemployment rate h-workers ')

   subplot(3,2,2),plot(Time_axis,irf_policy_a0(:,5),'-ko',Time_axis,irf_policy_bbench(:,5),':k',...
        Time_axis,irf_policy_aa(:,5),'--k.',Time_axis,irf_policy_bb(:,5),'-.k')
    
   
xlim([1 HORIZON]);
    grid on
    title('Unemployment rate')

         subplot(3,2,5),plot(Time_axis,irf_policy_a0(:,4),'-ko',Time_axis,irf_policy_bbench(:,4),':k',...
        Time_axis,irf_policy_aa(:,4),'--k.',Time_axis,irf_policy_bb(:,4),'-.k')
    
   
xlim([1 HORIZON]);
    grid on
		
 title('Interest rate ')

 subplot(3,2,1),plot(Time_axis,irf_policy_a0(:,3),'-ko',Time_axis,irf_policy_bbench(:,3),':k',...
        Time_axis,irf_policy_aa(:,3),'--k.',Time_axis,irf_policy_bb(:,3),'-.k')
   
   
xlim([1 HORIZON]);
    grid on
		
 title('Inflation')

 
 
 %   set(gca,'XTick',[ 4 8 12 16 20])
%set(gca,'XTickLabel',{'1', '2', '3', '4', '5'})
set(findobj('Type','line'),'LineWidth',1)
figure


 newpp=[0.25 , 0.25 , 8, 8];
      grid on
set(gcf,'PaperOrientation','portrait')
set(gcf,'PaperPosition',newpp)

newpp=[0.25 , 0.25 , 8, 8];
      grid on
set(gcf,'PaperOrientation','portrait')
set(gcf,'PaperPosition',newpp)
%set(gca,'XTick',[ 4 8 12 16 20])
%set(gca,'XTickLabel',{'1', '2', '3', '4', '5'})
%set(findobj('Type','line'),'LineWidth',2)

    subplot(3,2,3),plot(Time_axis,irf_policy_a0(:,1),'-ko',...
        Time_axis,irf_policy_bb(:,1),'-.k',Time_axis,irf_policy_rhon(:,1),':dk')
   
xlim([1 HORIZON]);
    grid on
		legend(solid, dasheddotted, diamonds)
 grid on
 title('Unemployment rate l-workers ')
 
 subplot(3,2,4),plot(Time_axis,irf_policy_a0(:,2),'-ko',...
        Time_axis,irf_policy_bb(:,2),'-.k',Time_axis,irf_policy_rhon(:,2),':dk')
    
   xlim([1 HORIZON]);
    grid on
		
 title('Unemployment rate h-workers ')

 
 
 subplot(3,2,6),plot(Time_axis,irf_policy_a0(:,6),'-ko',...
        Time_axis,irf_policy_bb(:,6),'-.k', Time_axis,irf_policy_rhon(:,6),':dk')
    
   xlim([1 HORIZON]);
    grid on
		
 title('Separation rate')

   subplot(3,2,2),plot(Time_axis,irf_policy_a0(:,5),'-ko',...
        Time_axis,irf_policy_bb(:,5),'-.k',Time_axis,irf_policy_rhon(:,5),':dk')
    
   
xlim([1 HORIZON]);
    grid on
    title('Unemployment rate')

         subplot(3,2,5),plot(Time_axis,irf_policy_a0(:,4),'-ko',...
        Time_axis,irf_policy_bb(:,4),'-.k',Time_axis,irf_policy_rhon(:,4),':dk')
    
   
xlim([1 HORIZON]);
    grid on
		
 title('Interest rate ')

 subplot(3,2,1),plot(Time_axis,irf_policy_a0(:,3),'-ko',...
        Time_axis,irf_policy_bb(:,3),'-.k',Time_axis,irf_policy_rhon(:,3),':dk')
   
   
xlim([1 HORIZON]);
    grid on
		
 title('Inflation')

 
 
 %   set(gca,'XTick',[ 4 8 12 16 20])
%set(gca,'XTickLabel',{'1', '2', '3', '4', '5'})
set(findobj('Type','line'),'LineWidth',1)

figure


%%%%%%Policy targeting zero U , for appendix 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
load policy_ntarget
HORIZON = size(xit_e1,1);
zzero=zeros(1,HORIZON);
Time_axis = [1:HORIZON];

share_nl = nl_e1*nl_ss./(n_e1*n_ss)*100;
share_nh = nh_e1*nh_ss./(n_e1*n_ss)*100;
share_scaled_ul = share_nl.*(u_e1*u_ss)/100;
share_scaled_uh = share_nh.*(u_e1*u_ss)/100;

irf_policy_ntarget = [unempl_l, unempl_h, Pi_e1, rn_e1, unempl,  rhon_e1 ];



 newpp=[0.25 , 0.25 , 8, 8];
      grid on
set(gcf,'PaperOrientation','portrait')
set(gcf,'PaperPosition',newpp)

newpp=[0.25 , 0.25 , 8, 8];
      grid on
set(gcf,'PaperOrientation','portrait')
set(gcf,'PaperPosition',newpp)
%set(gca,'XTick',[ 4 8 12 16 20])
%set(gca,'XTickLabel',{'1', '2', '3', '4', '5'})
%set(findobj('Type','line'),'LineWidth',2)

    subplot(3,2,3),plot(Time_axis,irf_policy_bbench(:,1),'-.k',Time_axis,irf_policy_ntarget(:,1),':sk')
   
xlim([1 HORIZON]);
    grid on
		legend(dotted, squares)
 grid on
 title('Unemployment rate l-workers ')
 
 subplot(3,2,4),plot(Time_axis,irf_policy_bbench(:,2),'-.k',Time_axis,irf_policy_ntarget(:,2),':sk')
    
   xlim([1 HORIZON]);
    grid on
		
 title('Unemployment rate h-workers ')

 
 
 subplot(3,2,6),plot(Time_axis,irf_policy_bbench(:,6),'-.k', Time_axis,irf_policy_ntarget(:,6),':sk')
    
   xlim([1 HORIZON]);
    grid on
		
 title('Separation rate')

   subplot(3,2,2),plot(Time_axis,irf_policy_bbench(:,5),'-.k',Time_axis,irf_policy_ntarget(:,5),':sk')
    
   
xlim([1 HORIZON]);
    grid on
    title('Unemployment rate')

         subplot(3,2,5),plot(Time_axis,irf_policy_bbench(:,4),'-.k',Time_axis,irf_policy_ntarget(:,4),':sk')
    
   
xlim([1 HORIZON]);
    grid on
		
 title('Interest rate ')

 subplot(3,2,1),plot(Time_axis,irf_policy_bbench(:,3),'-.k',Time_axis,irf_policy_ntarget(:,3),':sk')
   
   
xlim([1 HORIZON]);
    grid on
		
 title('Inflation')

 
 
 %   set(gca,'XTick',[ 4 8 12 16 20])
%set(gca,'XTickLabel',{'1', '2', '3', '4', '5'})
set(findobj('Type','line'),'LineWidth',1)

figure

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% FIG B_TEMP /   abar*abar_ss, Mu,

% BENCHMARK: std IT, policy_bbench // DOTTED
dotted = ['Policy (2): Respond to inflation (benchmark)'] 
% POLICY A: Expansionary omegay*N,omegay=0.4 policy_aa //DASHED
dashed = ['Policy (3): Respond to unemployment \omega_{u}=0.4'] 
% POLICY B: Expansionary omegay*N,omegay=0.8 policy_bb //dashedDOTTED
dasheddotted = ['Policy (4): Respond to unemployment \omega_{u}=0.8'] 
% POLICY A0: STRICT IT, policy_a0 //SOLID
solid = ['Policy (1): Price stability'] 
% POLICY RHON: react to layoff rate // diamond
diamonds = ['Policy (5): Respond to separation rate']

%%%% START price stability policy
load policy_a0
HORIZON = size(xit_e1,1);
zzero=zeros(1,HORIZON);
Time_axis = [1:HORIZON];

irf_policy_a0 = [mu_e1, surph_e1, abar_e1*rhon_ss, wage_tot_difference_l ];
%%%%%%%%%%%%% END PRICE STABILITY

load policy_bb
HORIZON = size(xit_e1,1);
zzero=zeros(1,HORIZON);
Time_axis = [1:HORIZON];

irf_policy_bb = [mu_e1, surph_e1, abar_e1*rhon_ss, wage_tot_difference_l ];

load policy_rhon
HORIZON = size(xit_e1,1);
zzero=zeros(1,HORIZON);
Time_axis = [1:HORIZON];

irf_policy_rhon = [mu_e1, surph_e1, abar_e1*rhon_ss, wage_tot_difference_l ];


newpp=[0.25 , 0.25 , 8, 8];
      grid on
set(gcf,'PaperOrientation','portrait')
set(gcf,'PaperPosition',newpp)
% BENCHMARK: std IT, policy_bbench // DOTTED
dotted = ['Policy (2): Respond to inflation (benchmark)'] 
% POLICY A: Expansionary omegay*N,omegay=0.4 policy_aa //DASHED
dashed = ['Policy (3): Respond to unemployment \omega_{u}=0.4'] 
% POLICY B: Expansionary omegay*N,omegay=0.8 policy_bb //dashedDOTTED
dasheddotted = ['Policy (4): Respond to unemployment \omega_{u}=0.8'] 
% POLICY A0: STRICT IT, policy_a0 //SOLID
solid = ['Policy (1): Price stability'] 
% POLICY RHON: react to layoff rate // diamond
diamonds = ['Policy (5): Respond to separation rate']

HORIZON = size(xit_e1,1);
zzero=zeros(1,HORIZON);
Time_axis = [1:HORIZON];


    subplot(2,1,1),plot(Time_axis,irf_policy_a0(:,1),'-ko', ...
       Time_axis,irf_policy_bb(:,1),'-.k',Time_axis,irf_policy_rhon(:,1),':dk')
   
xlim([1 HORIZON]);
    grid on
	title('Retail markup')
 %   set(gca,'XTick',[ 4 8 12 16 20])
%set(gca,'XTickLabel',{'1', '2', '3', '4', '5'})
set(findobj('Type','line'),'LineWidth',1)


    subplot(2,1,2),plot(Time_axis,irf_policy_a0(:,3),'-ko',...
       Time_axis,irf_policy_bb(:,3),'-.k',Time_axis,irf_policy_rhon(:,3),':dk')

xlim([1 HORIZON]);
    grid on
	title('Cutoff productivity l-workers - log-change')
 %   set(gca,'XTick',[ 4 8 12 16 20])
%set(gca,'XTickLabel',{'1', '2', '3', '4', '5'})
set(findobj('Type','line'),'LineWidth',1)

legend(solid, dasheddotted, diamonds)


figure


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% FIG B_TEMP /   abar*abar_ss, Mu,

% BENCHMARK: std IT, policy_bbench // DOTTED
dotted = ['Policy (2): Respond to inflation (benchmark)'] 
% POLICY A: Expansionary omegay*N,omegay=0.4 policy_aa //DASHED
dashed = ['Policy (3): Respond to unemployment \omega_{u}=0.4'] 
% POLICY B: Expansionary omegay*N,omegay=0.8 policy_bb //dashedDOTTED
dasheddotted = ['Policy (4): Respond to unemployment \omega_{u}=0.8'] 
% POLICY A0: STRICT IT, policy_a0 //SOLID
solid = ['Policy (1): Price stability'] 

%%%% START price stability policy
load policy_a0
HORIZON = size(xit_e1,1);
zzero=zeros(1,HORIZON);
Time_axis = [1:HORIZON];

irf_policy_a0 = [mu_e1, surph_e1, abar_e1*rhon_ss, wage_tot_difference_l ];
%%%%%%%%%%%%% END PRICE STABILITY


load policy_bbench
HORIZON = size(xit_e1,1);
zzero=zeros(1,HORIZON);
Time_axis = [1:HORIZON];

irf_policy_bbench = [mu_e1, surph_e1, abar_e1*rhon_ss, wage_tot_difference_l ];

load policy_bb
HORIZON = size(xit_e1,1);
zzero=zeros(1,HORIZON);
Time_axis = [1:HORIZON];

irf_policy_bb = [mu_e1, surph_e1, abar_e1*rhon_ss, wage_tot_difference_l ];

load policy_aa
HORIZON = size(xit_e1,1);
zzero=zeros(1,HORIZON);
Time_axis = [1:HORIZON];

irf_policy_aa = [mu_e1, surph_e1, abar_e1*rhon_ss, wage_tot_difference_l ];


newpp=[0.25 , 0.25 , 8, 8];
      grid on
set(gcf,'PaperOrientation','portrait')
set(gcf,'PaperPosition',newpp)

HORIZON = size(xit_e1,1);
zzero=zeros(1,HORIZON);
Time_axis = [1:HORIZON];


    subplot(2,1,1),plot(Time_axis,irf_policy_a0(:,1),'-ko', Time_axis,irf_policy_bbench(:,1),':k',...
       Time_axis,irf_policy_aa(:,1),'--k.',Time_axis,irf_policy_bb(:,1),'-.k',Time_axis,zzero(1,:),':')
   
xlim([1 HORIZON]);
    grid on
	title('Retail markup')
 %   set(gca,'XTick',[ 4 8 12 16 20])
%set(gca,'XTickLabel',{'1', '2', '3', '4', '5'})
set(findobj('Type','line'),'LineWidth',1)


    subplot(2,1,2),plot(Time_axis,irf_policy_a0(:,3),'-ko', Time_axis,irf_policy_bbench(:,3),':k',...
       Time_axis,irf_policy_aa(:,3),'--k.',Time_axis,irf_policy_bb(:,3),'-.k',Time_axis,zzero(1,:),':')

xlim([1 HORIZON]);
    grid on
	title('Cutoff productivity l-workers - log-change')
 %   set(gca,'XTick',[ 4 8 12 16 20])
%set(gca,'XTickLabel',{'1', '2', '3', '4', '5'})
set(findobj('Type','line'),'LineWidth',1)

legend(solid, dotted, dashed, dasheddotted)
figure


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%APPENDIX - FIGURES FOR ALTERNATIVE POLICIES


% BENCHMARK: std IT, policy_bbench // SOLID
solid = ['Policy(1): Respond to inflation (benchmark)'] 
% POLICY A0: STRICT IT, policy_a0 //DASHED
dashed = ['Policy (5): Price stability'] 
% POLICY B0: Expansionary omegay*Nl,omegay=0.5 policy_b0 //DOTTED
dotted = ['Policy (4): Respond to l-unemployment \omega_{ul}=0.5'] 


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% FIGURE 1POLICY - Unempl rate, PP from ss (subtract ss), and UNEMP SHARE
%%% l-WORKERS
%%%%% COLOR AREA so areas sum

load policy_bbench
HORIZON = size(xit_e1,1);
zzero=zeros(1,HORIZON);
Time_axis = [1:HORIZON];

share_nl = nl_e1*nl_ss./(n_e1*n_ss)*100;
share_nh = nh_e1*nh_ss./(n_e1*n_ss)*100;
share_scaled_ul = share_nl.*(u_e1*u_ss)/100
share_scaled_uh = share_nh.*(u_e1*u_ss)/100

irf_policy_bbench = [unempl_l, unempl_h, Pi_e1, rn_e1, unempl ];

u_diff = [];
u_d_cumul = [];
ineq_ratio = [];
symm_infl_cost = [];

ul_cumul = ones(1,10) ;
uh_cumul = ones(1,10);
y_cumul = ones(1,10);
Pi_cumul =  ones(1,10);
Pi_cumul(1)=nan;

for count = 1:size(xit_e1,1)
    ul_cumul(count) = sum(share_scaled_ul(1:count,1));
    uh_cumul(count) = sum(share_scaled_uh(1:count,1));
    y_cumul(count) = sum(y_e1(1:count,1));
    ineq_ratio(count) = ul_cumul(count)/uh_cumul(count);
end

display('initial level unemployment for sacrifice ratio')
u_initial = 5.9491
pause

u_diff = unempl(2:size(xit_e1,1)) - u_initial;
u_diff = [0; u_diff];
for count = 1:size(xit_e1,1)
    Pi_cumul(count) = sum(abs(Pi_e1(2:count,1)));
    u_d_cumul(count) = sum(u_diff(1:count,1));
end

u_d_cumul(1) = nan;
u_diff(1) = nan;
Pi_cumul(1)=nan;
symm_infl_cost_cumul = Pi_cumul./u_d_cumul;
symm_infl_cost = Pi_cumul'./u_diff;

display('policy bbench') 
display('sac ratio // sac ratio CUMUL //  ineq ratio // cumul y // cumul ul_share // cumul uh_share')
policy_matrix = [-symm_infl_cost(8), -symm_infl_cost_cumul(8), ineq_ratio(8), y_cumul(8), ul_cumul(8), uh_cumul(8)]
pause



load policy_b0
HORIZON = size(xit_e1,1);
zzero=zeros(1,HORIZON);
Time_axis = [1:HORIZON];

share_nl = nl_e1*nl_ss./(n_e1*n_ss)*100;
share_nh = nh_e1*nh_ss./(n_e1*n_ss)*100;
share_scaled_ul = share_nl.*(u_e1*u_ss)/100;
share_scaled_uh = share_nh.*(u_e1*u_ss)/100;

irf_policy_bb = [unempl_l, unempl_h, Pi_e1, rn_e1, unempl ];

u_diff = [];
u_d_cumul = [];
ineq_ratio = [];
symm_infl_cost = [];

ul_cumul = ones(1,10) ;
uh_cumul = ones(1,10);
y_cumul = ones(1,10);
Pi_cumul =  ones(1,10);
Pi_cumul(1)=nan;

for count = 1:size(xit_e1,1)
    ul_cumul(count) = sum(share_scaled_ul(1:count,1));
    uh_cumul(count) = sum(share_scaled_uh(1:count,1));
    y_cumul(count) = sum(y_e1(1:count,1));
    ineq_ratio(count) = ul_cumul(count)/uh_cumul(count);
end

u_diff = unempl(2:size(xit_e1,1)) - u_initial;
u_diff = [0; u_diff];
for count = 1:size(xit_e1,1)
    Pi_cumul(count) = sum(abs(Pi_e1(2:count,1)));
    u_d_cumul(count) = sum(u_diff(1:count,1));
end

u_d_cumul(1) = nan;
u_diff(1) = nan;
Pi_cumul(1)=nan;
symm_infl_cost_cumul = Pi_cumul./u_d_cumul;
symm_infl_cost = Pi_cumul'./u_diff;

display('policy b0') 
display('sac ratio // sac ratio CUMUL //  ineq ratio // cumul y // cumul ul_share // cumul uh_share')
policy_matrix = [-symm_infl_cost(8), -symm_infl_cost_cumul(8), ineq_ratio(8), y_cumul(8), ul_cumul(8), uh_cumul(8)]

%%%% for Marginal Sac Ratio
Pi_diff_m = Pi_e1 - Pi_a0;
unempl_diff_m = unempl - unempl_a0;

for count = 1:size(xit_e1,1)
    Pi_cumul_m(count) = sum(Pi_diff_m(1:count,1));
    unempl_cumul_m(count) = sum(unempl_diff_m(1:count,1));
end

sac_ratio_m = Pi_cumul_m./unempl_cumul_m;
sac_ratio_m'

display('marginal sac ratio CUMUL policy b0 / respond to l-unempl relative to price stability (A0)')
policy_matrix2 = [-sac_ratio_m(8)]
pause
%%%%
%%%%% END b0 POLICY

pause


load policy_a0
HORIZON = size(xit_e1,1);
zzero=zeros(1,HORIZON);
Time_axis = [1:HORIZON];

share_nl = nl_e1*nl_ss./(n_e1*n_ss)*100;
share_nh = nh_e1*nh_ss./(n_e1*n_ss)*100;
share_scaled_ul = share_nl.*(u_e1*u_ss)/100;
share_scaled_uh = share_nh.*(u_e1*u_ss)/100;

irf_policy_aa = [unempl_l, unempl_h, Pi_e1, rn_e1, unempl ];

u_diff = [];
u_d_cumul = [];
ineq_ratio = [];
symm_infl_cost = [];

ul_cumul = ones(1,10) ;
uh_cumul = ones(1,10);
y_cumul = ones(1,10);
Pi_cumul =  ones(1,10);
Pi_cumul(1)=nan;

for count = 1:size(xit_e1,1)
    ul_cumul(count) = sum(share_scaled_ul(1:count,1));
    uh_cumul(count) = sum(share_scaled_uh(1:count,1));
    y_cumul(count) = sum(y_e1(1:count,1));
    ineq_ratio(count) = ul_cumul(count)/uh_cumul(count);
end

u_diff = unempl(2:size(xit_e1,1)) - u_initial;
u_diff = [0; u_diff];
for count = 1:size(xit_e1,1)
    Pi_cumul(count) = sum(abs(Pi_e1(2:count,1)));
    u_d_cumul(count) = sum(u_diff(1:count,1));
end

u_d_cumul(1) = nan;
u_diff(1) = nan;
Pi_cumul(1)=nan;
symm_infl_cost_cumul = Pi_cumul./u_d_cumul;
symm_infl_cost = Pi_cumul'./u_diff;

display('policy a0') 
display('sac ratio // sac ratio CUMUL //  ineq ratio // cumul y // cumul ul_share // cumul uh_share')
policy_matrix = [-symm_infl_cost(8), -symm_infl_cost_cumul(8), ineq_ratio(8), y_cumul(8), ul_cumul(8), uh_cumul(8)]

pause

   newpp=[0.25 , 0.25 , 8, 8];
      grid on
set(gcf,'PaperOrientation','portrait')
set(gcf,'PaperPosition',newpp)

newpp=[0.25 , 0.25 , 8, 8];
      grid on
set(gcf,'PaperOrientation','portrait')
set(gcf,'PaperPosition',newpp)
%set(gca,'XTick',[ 4 8 12 16 20])
%set(gca,'XTickLabel',{'1', '2', '3', '4', '5'})
%set(findobj('Type','line'),'LineWidth',2)

    subplot(3,2,3),plot(Time_axis,irf_policy_bbench(:,1),'k',...
        Time_axis,irf_policy_aa(:,1),'--k.',Time_axis,irf_policy_bb(:,1),'-.k',Time_axis,zzero(1,:),':')
   
xlim([1 HORIZON]);
    grid on
		legend(solid, dashed, dotted)
 grid on
 title('Unemployment rate l-workers ')
 
   subplot(3,2,4),plot(Time_axis,irf_policy_bbench(:,2),'k',...
        Time_axis,irf_policy_aa(:,2),'--k.',Time_axis,irf_policy_bb(:,2),'-.k',Time_axis,zzero(1,:),':')
   
   
xlim([1 HORIZON]);
    grid on
		
 title('Unemployment rate h-workers ')

    subplot(3,2,2),plot(Time_axis,irf_policy_bbench(:,3),'k',...
        Time_axis,irf_policy_aa(:,3),'--k.',Time_axis,irf_policy_bb(:,3),'-.k',Time_axis,zzero(1,:),':')
   
   
xlim([1 HORIZON]);
    grid on
		 title('Inflation')

subplot(3,2,5),plot(Time_axis,irf_policy_bbench(:,4),'k',...
        Time_axis,irf_policy_aa(:,4),'--k.',Time_axis,irf_policy_bb(:,4),'-.k',Time_axis,zzero(1,:),':')
   
   
xlim([1 HORIZON]);
    grid on
		
 title('Interest rate ')


subplot(3,2,1),plot(Time_axis,irf_policy_bbench(:,5),'k',...
        Time_axis,irf_policy_aa(:,5),'--k.',Time_axis,irf_policy_bb(:,5),'-.k',Time_axis,zzero(1,:),':')
   
   
xlim([1 HORIZON]);
    grid on
		
 title('Unemployment rate ')

 
 %   set(gca,'XTick',[ 4 8 12 16 20])
%set(gca,'XTickLabel',{'1', '2', '3', '4', '5'})
set(findobj('Type','line'),'LineWidth',1)
figure



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% FIG B_TEMP /   abar*abar_ss, Mu,


load policy_bbench
HORIZON = size(xit_e1,1);
zzero=zeros(1,HORIZON);
Time_axis = [1:HORIZON];

irf_policy_bbench = [mu_e1, surph_e1, abar_e1*rhon_ss, wage_tot_difference_l ];

load policy_b0
HORIZON = size(xit_e1,1);
zzero=zeros(1,HORIZON);
Time_axis = [1:HORIZON];

irf_policy_bb = [mu_e1, surph_e1, abar_e1*rhon_ss, wage_tot_difference_l ];

load policy_a0
HORIZON = size(xit_e1,1);
zzero=zeros(1,HORIZON);
Time_axis = [1:HORIZON];

irf_policy_aa = [mu_e1, surph_e1, abar_e1*rhon_ss, wage_tot_difference_l ];


newpp=[0.25 , 0.25 , 8, 8];
      grid on
set(gcf,'PaperOrientation','portrait')
set(gcf,'PaperPosition',newpp)

HORIZON = size(xit_e1,1);
zzero=zeros(1,HORIZON);
Time_axis = [1:HORIZON];
   
    subplot(2,1,1),plot(Time_axis,irf_policy_bbench(:,1),'k',...
       Time_axis,irf_policy_aa(:,1),'--k.',Time_axis,irf_policy_bb(:,1),'-.k',Time_axis,zzero(1,:),':')
   
xlim([1 HORIZON]);
    grid on
	title('Retail markup')
 %   set(gca,'XTick',[ 4 8 12 16 20])
%set(gca,'XTickLabel',{'1', '2', '3', '4', '5'})
set(findobj('Type','line'),'LineWidth',1)


subplot(2,1,2),plot(Time_axis,irf_policy_bbench(:,3),'k',...
       Time_axis,irf_policy_aa(:,3),'--k.',Time_axis,irf_policy_bb(:,3),'-.k',Time_axis,zzero(1,:),':')
   
xlim([1 HORIZON]);
    grid on
	title('Cutoff productivity l-workers - log-change')
 %   set(gca,'XTick',[ 4 8 12 16 20])
%set(gca,'XTickLabel',{'1', '2', '3', '4', '5'})
set(findobj('Type','line'),'LineWidth',1)

legend(solid, dashed, dotted)



