%  nberdates_shading.m  
%  Carl Walsh 2/3/15, updates Aug 2021
%  Adds shaded bars to indicate NBER business cycles
%  Run after plot command
%
%  Official NBER recession dates, from
%  http://www.nber.org/cycles/cyclesmain.html  (see NBERcycles.html)
%  
% dates are strings in nber_dates.xlxs
% use instead of recessionplots; command for darker shading

%% Import the data
TNBER = 34; % row of last business cycle in nber_dates.xlsx
% Adjust for computer: cewjl for Surface, CEW for X1
[~, ~, nberdates] = xlsread('nber_dates.xlsx','nber_dates','F2:G35');
nberdates(cellfun(@(x) ~isempty(x) && isnumeric(x) && isnan(x),nberdates)) = {''};

%%
startdates  = nberdates(:,1);
enddates    = nberdates(:,2);
[startdates enddates];

%% 
stdates = datevec(startdates(14:TNBER),'dd/mm/yyyy');
eddates = datevec(enddates(14:TNBER),'dd/mm/yyyy');
%%
st      = datenum(stdates);
ed      = datenum(eddates);
%%
% This code below is from Chad Jones
% From Chad Jones's web page: http://web.stanford.edu/~chadj/ChadMatlabFunctions.html
curax=axis;
indx1=find(ed>curax(1));    % First recession to include;
indx2=find(st<curax(2));    % Last recession to include;
indx1=indx1(1);
%%
indx2=indx2(length(indx2));
if st(indx1)<curax(1);
  st(indx1)=curax(1);
end;
if  ed(indx2)>curax(2);
    ed(indx2)=curax(2);
end;

colorstr = [0.8 0.8 0.8];       % Gray
%colorstr = [159 182 205]/256;  % Blue
%%
%shade(st(indx1:indx2),ed(indx1:indx2),colorstr);
%  From Chad Jones's web page: http://web.stanford.edu/~chadj/ChadMatlabFunctions.html
% from his shade.m
%curax=axis;
stdate = st(indx1:indx2);
eddate = ed(indx1:indx2);
y=[curax(3) curax(4) curax(4) curax(3)];
hold on;
for i=1:length(stdate);
  x=[stdate(i) stdate(i) eddate(i) eddate(i)];
  fill(x,y,colorstr);
end;

%%
set(gca,'children',flipud(get(gca,'children')))


